import TextSearchModel from "@esko/web-viewer/svg/TextSearchModel";

class MultiPageTextSearchModel extends TextSearchModel {
	constructor(f, channelName, textModel, matchingPages) {
		super(f, channelName, textModel);

		this._matchingPages = matchingPages;
		this._currentPageIndex = 0;
	}

	previous() {
		const selectedIndex = this.getHighlightedIndex();

		if (selectedIndex === 0 && this._currentPageIndex !== 0) {
			this._currentPageIndex -= 1;
			this._changePage();
		} else {
			super.previous();
		}
	}

	next() {
		const hitCountCurrentPage = this.hitCount();
		const selectedIndex = this.getHighlightedIndex();

		if (selectedIndex === hitCountCurrentPage - 1 && this._currentPageIndex < this._matchingPages.length - 1) {
			this._currentPageIndex += 1;
			this._changePage();
		} else {
			super.next();
		}
	}

	_changePage() {
		const docController = this.f.getDocumentController();
		const documentVersion = docController.getActiveDocument().getDocumentVersion();
		const page = parseInt(this._matchingPages[this._currentPageIndex], 10);

		docController.changeActivePage(documentVersion.getPage(page));
	}

	hasNext() {
		return this.getHighlightedIndex() < this.hitCount() - 1 || this._currentPageIndex < this._matchingPages.length - 1;
	}

	hasPrevious() {
		return this._i > 0 || this._currentPageIndex > 0;
	}

	getNumberOfComingPages() {
		return this._matchingPages.length - this._currentPageIndex - 1;
	}

	getNumberOfPreviousPages() {
		return this._currentPageIndex;
	}
}

export default MultiPageTextSearchModel;
